==> jc-1.4.0.tar.gz: jas/InvokeinterfaceOperand.h <==
// class jas.InvokeinterfaceOperand

// class file dependencies
// @dep_class 2c401db3553feabf jas_InsnOperand
// @dep_class 8f7aaa4388b2c789 jas_InvokeinterfaceOperand
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header jas_InsnOperand

#include "jas/InsnOperand.h"

#ifndef _JC_jas_InvokeinterfaceOperand_H_
#define _JC_jas_InvokeinterfaceOperand_H_

// Forward structure declarations
struct _jc_jas_CP$object;
struct _jc_jas_ClassEnv$object;
struct _jc_jas_CodeAttr$object;
struct _jc_java_io_DataOutputStream$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_jas_InvokeinterfaceOperand$sub_refs	_jc_jas_InvokeinterfaceOperand$sub_refs;
typedef struct _jc_jas_InvokeinterfaceOperand$sub_nonrefs	_jc_jas_InvokeinterfaceOperand$sub_nonrefs;
typedef struct _jc_jas_InvokeinterfaceOperand$refs	_jc_jas_InvokeinterfaceOperand$refs;
typedef struct _jc_jas_InvokeinterfaceOperand$nonrefs	_jc_jas_InvokeinterfaceOperand$nonrefs;
typedef struct _jc_jas_InvokeinterfaceOperand$object	_jc_jas_InvokeinterfaceOperand$object;

typedef const struct _jc_jas_InvokeinterfaceOperand$vmethods	_jc_jas_InvokeinterfaceOperand$vmethods;
typedef const struct _jc_jas_InvokeinterfaceOperand$vtable	_jc_jas_InvokeinterfaceOperand$vtable;
typedef const struct _jc_jas_InvokeinterfaceOperand$vtype	_jc_jas_InvokeinterfaceOperand$vtype;

// Constructors
extern void _jc_jas_InvokeinterfaceOperand$method$_init$ac87c5b24fe5e7ef(_jc_env *, struct _jc_jas_InvokeinterfaceOperand$object *, struct _jc_jas_CP$object *, jint);

// Virtual methods
extern void _jc_jas_InvokeinterfaceOperand$method$resolve$f7bbca8128967cc2(_jc_env *, struct _jc_jas_InvokeinterfaceOperand$object *, struct _jc_jas_ClassEnv$object *);
extern jint _jc_jas_InvokeinterfaceOperand$method$size$ed865933e174f90a(_jc_env *, struct _jc_jas_InvokeinterfaceOperand$object *, struct _jc_jas_ClassEnv$object *, struct _jc_jas_CodeAttr$object *);
extern void _jc_jas_InvokeinterfaceOperand$method$write$d61e8c36d8c1cacd(_jc_env *, struct _jc_jas_InvokeinterfaceOperand$object *, struct _jc_jas_ClassEnv$object *, struct _jc_jas_CodeAttr$object *, struct _jc_java_io_DataOutputStream$object *);

// Virtual method descriptors
extern _jc_method _jc_jas_InvokeinterfaceOperand$method_info$resolve$f7bbca8128967cc2;
extern _jc_method _jc_jas_InvokeinterfaceOperand$method_info$size$ed865933e174f90a;
extern _jc_method _jc_jas_InvokeinterfaceOperand$method_info$write$d61e8c36d8c1cacd;

// Virtual methods structure
struct _jc_jas_InvokeinterfaceOperand$vmethods {
	void	(*resolve$f7bbca8128967cc2)(_jc_env *, struct _jc_jas_InvokeinterfaceOperand$object *, struct _jc_jas_ClassEnv$object *);
	jint	(*size$ed865933e174f90a)(_jc_env *, struct _jc_jas_InvokeinterfaceOperand$object *, struct _jc_jas_ClassEnv$object *, struct _jc_jas_CodeAttr$object *);
	void	(*write$d61e8c36d8c1cacd)(_jc_env *, struct _jc_jas_InvokeinterfaceOperand$object *, struct _jc_jas_ClassEnv$object *, struct _jc_jas_CodeAttr$object *, struct _jc_java_io_DataOutputStream$object *);
};

// Vtable
struct _jc_jas_InvokeinterfaceOperand$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_jas_InsnOperand$vmethods	jas_InsnOperand;
	_jc_jas_InvokeinterfaceOperand$vmethods	jas_InvokeinterfaceOperand;
};

// Vtype
struct _jc_jas_InvokeinterfaceOperand$vtype {
	_jc_type			type;
	_jc_jas_InvokeinterfaceOperand$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_jas_InvokeinterfaceOperand$sub_refs {
	struct _jc_jas_CP$object	*cpe;
};

// Reference instance fields (object)
struct _jc_jas_InvokeinterfaceOperand$refs {
    _jc_jas_InvokeinterfaceOperand$sub_refs	jas_InvokeinterfaceOperand;
    _jc_jas_InsnOperand$sub_refs	jas_InsnOperand;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_jas_InvokeinterfaceOperand$sub_nonrefs {
	jint	nargs;
};

// Non-reference instance fields (object)
struct _jc_jas_InvokeinterfaceOperand$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_jas_InsnOperand$sub_nonrefs	jas_InsnOperand;
    _jc_jas_InvokeinterfaceOperand$sub_nonrefs	jas_InvokeinterfaceOperand;
};

// Object instance structure
struct _jc_jas_InvokeinterfaceOperand$object {
	_jc_jas_InvokeinterfaceOperand$refs	refs[0];
	_jc_word		lockword;
	_jc_jas_InvokeinterfaceOperand$vtype	*vtype;
	_jc_jas_InvokeinterfaceOperand$nonrefs	nonrefs;
};

// Type structure
extern _jc_jas_InvokeinterfaceOperand$vtype _jc_jas_InvokeinterfaceOperand$type;

// Array types class info structures
_JC_DECL_ARRAYS(jas_InvokeinterfaceOperand, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_jas_InvokeinterfaceOperand$class_object;

#endif	/* _JC_jas_InvokeinterfaceOperand_H_ */

==> jc-1.4.6.tar.gz: jas/InvokeinterfaceOperand.h <==
// class jas.InvokeinterfaceOperand

// class file dependencies
// @dep_class 2c401db3553feabf jas_InsnOperand
// @dep_class 8f7aaa4388b2c789 jas_InvokeinterfaceOperand
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header jas_InsnOperand

#include "jas/InsnOperand.h"

#ifndef _JC_jas_InvokeinterfaceOperand_H_
#define _JC_jas_InvokeinterfaceOperand_H_

// Forward structure declarations
struct _jc_jas_CP$object;
struct _jc_jas_ClassEnv$object;
struct _jc_jas_CodeAttr$object;
struct _jc_java_io_DataOutputStream$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_jas_InvokeinterfaceOperand$sub_refs	_jc_jas_InvokeinterfaceOperand$sub_refs;
typedef struct _jc_jas_InvokeinterfaceOperand$sub_nonrefs	_jc_jas_InvokeinterfaceOperand$sub_nonrefs;
typedef struct _jc_jas_InvokeinterfaceOperand$refs	_jc_jas_InvokeinterfaceOperand$refs;
typedef struct _jc_jas_InvokeinterfaceOperand$nonrefs	_jc_jas_InvokeinterfaceOperand$nonrefs;
typedef struct _jc_jas_InvokeinterfaceOperand$object	_jc_jas_InvokeinterfaceOperand$object;

typedef const struct _jc_jas_InvokeinterfaceOperand$vmethods	_jc_jas_InvokeinterfaceOperand$vmethods;
typedef const struct _jc_jas_InvokeinterfaceOperand$vtable	_jc_jas_InvokeinterfaceOperand$vtable;
typedef const struct _jc_jas_InvokeinterfaceOperand$vtype	_jc_jas_InvokeinterfaceOperand$vtype;

// Constructors
extern void _jc_jas_InvokeinterfaceOperand$method$_init$ac87c5b24fe5e7ef(_jc_env *, struct _jc_jas_InvokeinterfaceOperand$object *, struct _jc_jas_CP$object *, jint) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_jas_InvokeinterfaceOperand$method$resolve$f7bbca8128967cc2(_jc_env *, struct _jc_jas_InvokeinterfaceOperand$object *, struct _jc_jas_ClassEnv$object *) _JC_JCNI_ATTR;
extern jint _jc_jas_InvokeinterfaceOperand$method$size$ed865933e174f90a(_jc_env *, struct _jc_jas_InvokeinterfaceOperand$object *, struct _jc_jas_ClassEnv$object *, struct _jc_jas_CodeAttr$object *) _JC_JCNI_ATTR;
extern void _jc_jas_InvokeinterfaceOperand$method$write$d61e8c36d8c1cacd(_jc_env *, struct _jc_jas_InvokeinterfaceOperand$object *, struct _jc_jas_ClassEnv$object *, struct _jc_jas_CodeAttr$object *, struct _jc_java_io_DataOutputStream$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_jas_InvokeinterfaceOperand$method_info$resolve$f7bbca8128967cc2;
extern _jc_method _jc_jas_InvokeinterfaceOperand$method_info$size$ed865933e174f90a;
extern _jc_method _jc_jas_InvokeinterfaceOperand$method_info$write$d61e8c36d8c1cacd;

// Virtual methods structure
struct _jc_jas_InvokeinterfaceOperand$vmethods {
	void	(*resolve$f7bbca8128967cc2)(_jc_env *, struct _jc_jas_InvokeinterfaceOperand$object *, struct _jc_jas_ClassEnv$object *) _JC_JCNI_ATTR;
	jint	(*size$ed865933e174f90a)(_jc_env *, struct _jc_jas_InvokeinterfaceOperand$object *, struct _jc_jas_ClassEnv$object *, struct _jc_jas_CodeAttr$object *) _JC_JCNI_ATTR;
	void	(*write$d61e8c36d8c1cacd)(_jc_env *, struct _jc_jas_InvokeinterfaceOperand$object *, struct _jc_jas_ClassEnv$object *, struct _jc_jas_CodeAttr$object *, struct _jc_java_io_DataOutputStream$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_jas_InvokeinterfaceOperand$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_jas_InsnOperand$vmethods	jas_InsnOperand;
	_jc_jas_InvokeinterfaceOperand$vmethods	jas_InvokeinterfaceOperand;
};

// Vtype
struct _jc_jas_InvokeinterfaceOperand$vtype {
	_jc_type			type;
	_jc_jas_InvokeinterfaceOperand$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_jas_InvokeinterfaceOperand$sub_refs {
	struct _jc_jas_CP$object	*cpe;
};

// Reference instance fields (object)
struct _jc_jas_InvokeinterfaceOperand$refs {
    _jc_jas_InvokeinterfaceOperand$sub_refs	jas_InvokeinterfaceOperand;
    _jc_jas_InsnOperand$sub_refs	jas_InsnOperand;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_jas_InvokeinterfaceOperand$sub_nonrefs {
	jint	nargs;
};

// Non-reference instance fields (object)
struct _jc_jas_InvokeinterfaceOperand$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_jas_InsnOperand$sub_nonrefs	jas_InsnOperand;
    _jc_jas_InvokeinterfaceOperand$sub_nonrefs	jas_InvokeinterfaceOperand;
};

// Object instance structure
struct _jc_jas_InvokeinterfaceOperand$object {
	_jc_jas_InvokeinterfaceOperand$refs	refs[0];
	_jc_word		lockword;
	_jc_jas_InvokeinterfaceOperand$vtype	*vtype;
	_jc_jas_InvokeinterfaceOperand$nonrefs	nonrefs;
};

// Type structure
extern _jc_jas_InvokeinterfaceOperand$vtype _jc_jas_InvokeinterfaceOperand$type;

// Array types class info structures
_JC_DECL_ARRAYS(jas_InvokeinterfaceOperand, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_jas_InvokeinterfaceOperand$class_object;

#endif	/* _JC_jas_InvokeinterfaceOperand_H_ */
